@@ -1,5 +1,4 @@
-specs_file <- system.file("extdata", "global-mpi-specs.csv", package = "mpindex")
-mpi_specs <- define_mpi_specs(specs_file, .uid = 'uuid')
+mpi_specs <- use_global_mpi_specs(.uid = "uuid")
 
 test_that("dimension is returned correctly", {
   dp <- df_household |>
@@ -13,13 +12,6 @@ test_that("dimension is returned correctly", {
 })
 
 
-test_that("error if specs file is not defined", {
-  expect_error(
-    define_deprivation(df_household, drinking_water, drinking_water == 2),
-    'MPI specifications must be defined first.'
-  )
-})
-
 test_that("collapsing is correctly implemented", {
   dp <- df_household_roster |>
     define_deprivation(
